@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@
 from .services.distance_calculator_service import DistanceCalculatorServiceClient
 from .services.distance_calculator_service import DistanceCalculatorServiceAsyncClient
 
+from .types.service import BatchDistanceRequest
+from .types.service import BatchDistanceResponse
 from .types.service import DistanceRequest
 from .types.service import DistanceResponse
 from .types.service import Leg
@@ -25,6 +27,8 @@ from .types.service import Point
 
 __all__ = (
     'DistanceCalculatorServiceAsyncClient',
+'BatchDistanceRequest',
+'BatchDistanceResponse',
 'DistanceCalculatorServiceClient',
 'DistanceRequest',
 'DistanceResponse',
