@@ -128,6 +128,11 @@ class VesselServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.list_dark_period_events: gapic_v1.method.wrap_method(
+                self.list_dark_period_events,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.get_ais_summary: gapic_v1.method.wrap_method(
                 self.get_ais_summary,
                 default_timeout=None,
@@ -162,6 +167,15 @@ class VesselServiceTransport(abc.ABC):
             ]]:
         raise NotImplementedError()
 
+    @property
+    def list_dark_period_events(self) -> Callable[
+            [service.ListDarkPeriodEventsRequest],
+            Union[
+                service.ListDarkPeriodEventsResponse,
+                Awaitable[service.ListDarkPeriodEventsResponse]
+            ]]:
+        raise NotImplementedError()
+
     @property
     def get_ais_summary(self) -> Callable[
             [service.GetAisSummaryRequest],
