@@ -258,6 +258,8 @@ class VesselServiceGrpcTransport(VesselServiceTransport):
             service.ListStoppageEventsResponse]:
         r"""Return a callable for the list stoppage events method over gRPC.
 
+        Fetches ais based stoppage events for a single vessel
+
         Returns:
             Callable[[~.ListStoppageEventsRequest],
                     ~.ListStoppageEventsResponse]:
@@ -276,6 +278,34 @@ class VesselServiceGrpcTransport(VesselServiceTransport):
             )
         return self._stubs['list_stoppage_events']
 
+    @property
+    def list_dark_period_events(self) -> Callable[
+            [service.ListDarkPeriodEventsRequest],
+            service.ListDarkPeriodEventsResponse]:
+        r"""Return a callable for the list dark period events method over gRPC.
+
+        Fetches ais based dark period events for a single
+        vessel. A dark period event, is where a vessel has not
+        transmitted AIS data for a period greater than 48 hours.
+
+        Returns:
+            Callable[[~.ListDarkPeriodEventsRequest],
+                    ~.ListDarkPeriodEventsResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'list_dark_period_events' not in self._stubs:
+            self._stubs['list_dark_period_events'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.vessels.v3.VesselService/ListDarkPeriodEvents',
+                request_serializer=service.ListDarkPeriodEventsRequest.serialize,
+                response_deserializer=service.ListDarkPeriodEventsResponse.deserialize,
+            )
+        return self._stubs['list_dark_period_events']
+
     @property
     def get_ais_summary(self) -> Callable[
             [service.GetAisSummaryRequest],
